@@ -13,10 +13,9 @@ from urllib.parse import parse_qsl, quote, urlencode, urljoin, urlsplit
 
 #  import aiohttp
 import httpx
-import yarl
 
 
-__version__ = "0.25.5"
+__version__ = "0.25.7"
 __project__ = "aioauth-client"
 __author__ = "Kirill Klenov <horneds@gmail.com>"
 __license__ = "MIT"
@@ -69,14 +68,7 @@ class HmacSha1Signature(Signature):
     def sign(self, consumer_secret: str, method: str, url: str, oauth_token_secret: str = None,
              escape: bool = False, **params) -> str:
         """Create a signature using HMAC-SHA1."""
-        if escape:
-            query = '&'.join(["%s=%s" % item for item in sorted([
-                (self._escape(k), self._escape(v)) for k, v in params.items()
-            ])])
-
-        else:
-            url, query = str(yarl.URL(url).with_query(sorted(params.items()))).split('?', 1)
-
+        query = urlencode(params)
         signature = "&".join(map(self._escape, (method.upper(), url, query)))
 
         key = self._escape(consumer_secret) + "&"
@@ -87,20 +79,6 @@ class HmacSha1Signature(Signature):
         return base64.b64encode(hashed.digest()).decode()
 
 
-class PlaintextSignature(Signature):
-    """PLAINTEXT signature-method."""
-
-    name = 'PLAINTEXT'
-
-    def sign(self, consumer_secret: str, method: str, url: str, oauth_token_secret: str = None,
-             **params) -> str:
-        """Create a signature using PLAINTEXT."""
-        key = self._escape(consumer_secret) + '&'
-        if oauth_token_secret:
-            key += self._escape(oauth_token_secret)
-        return key
-
-
 class ClientRegistry(type):
     """Meta class to register OAUTH clients."""
 
@@ -149,11 +127,15 @@ class Client(object, metaclass=ClientRegistry):
         """String representation."""
         return f"<{self}>"
 
-    async def _request(self, method: str, url: str, **options) -> t.Union[t.Dict, str]:
+    async def _request(self, method: str, url: str, raise_for_status: bool = False,
+                       **options) -> t.Union[t.Dict, str]:
         """Make a request through HTTPX."""
         transport = self.transport or httpx.AsyncClient()
         async with transport as client:
             response = await client.request(method, url, **options)
+            if raise_for_status and response.status_code >= 300:
+                raise OAuthException(str(response))
+
             self.logger.debug("Request %s: %s %r", method, url, options)
             if 'json' in response.headers.get('CONTENT-TYPE'):
                 return response.json()
@@ -171,7 +153,7 @@ class Client(object, metaclass=ClientRegistry):
             raise NotImplementedError(
                 'The provider doesnt support user_info method.')
 
-        data = await self.request('GET', self.user_info_url, **options)
+        data = await self.request('GET', self.user_info_url, raise_for_status=True, **options)
         user = User(**dict(self.user_parse(data)))
         return user, data
 
@@ -246,7 +228,8 @@ class OAuth1Client(Client):
     async def get_request_token(self, **params) -> t.Tuple[str, str, t.Any]:
         """Get a request_token and request_token_secret from OAuth1 provider."""
         params = dict(self.params, **params)
-        data = await self.request('GET', self.request_token_url, params=params)
+        data = await self.request(
+            'GET', self.request_token_url, raise_for_status=True, params=params)
         if not isinstance(data, dict):
             return '', '', data
 
@@ -269,8 +252,9 @@ class OAuth1Client(Client):
                 'Failed to obtain OAuth 1.0 access token. '
                 'Request token is invalid')
 
-        data = await self.request('POST', self.access_token_url, headers=headers, params={
-            'oauth_verifier': oauth_verifier, 'oauth_token': request_token})
+        data = await self.request(
+            'POST', self.access_token_url, raise_for_status=True, headers=headers,
+            params={'oauth_verifier': oauth_verifier, 'oauth_token': request_token})
 
         self.oauth_token = data.get('oauth_token')
         self.oauth_token_secret = data.get('oauth_token_secret')
@@ -337,7 +321,7 @@ class OAuth2Client(Client):
 
         self.access_token = None
         data = await self.request(
-            'POST', self.access_token_url, data=payload, headers=headers)
+            'POST', self.access_token_url, raise_for_status=True, data=payload, headers=headers)
 
         if not isinstance(data, dict):
             return '', data
